@@ -1,5 +1,6 @@
-from .api import Database, FeatureProxy, download_database, upload_database
+from .api import Database, FeatureProxy
 from .data_object import DataObject
 from .factory import make_root_db, AudioFileWalker
 from .metadata import Metadata
 from .transforms import file_to_fft, default_extract_func, N_FFT, HOP_LENGTH, SR
+from .freqnet_db import freqnet_db
