@@ -18,14 +18,4 @@ class LearnablePad1d(nn.Module):
         if self.pad is None:
             return x
         self.pad = self.pad.to(x)
-        return torch.cat((torch.stack([self.pad] * x.size(0)), x)[::self.side], dim=-1)
-
-
-    def receptive_field(self):
-        shifts = []
-        for i, layer in enumerate(self.layers):
-            if shifts[-1] > layer.shift():
-                shifts += [shifts[-1] + layer.shift()]
-            else:
-                shifts += [layer.shift()]
-        return sum(shifts)
\ No newline at end of file
+        return torch.cat((torch.stack([self.pad] * x.size(0)), x)[::self.side], dim=-1)
\ No newline at end of file
